@@ -465,6 +465,14 @@ void VTCore::CheckMsgQ()
                         #endif
 			break;
 
+		    case DSP_LOOP_FLASH:
+			mprintf("[%d/%d] Loop FLASH\n",m_reg.cardnum,msgq[2]);
+			rmess[0] = DSP_LLOOP_FLASH;
+			rmess[1] = DSP_LOOP_FLASH;
+			rmess[2] = msgq[2];
+			m_reg.upmess->Write(rmess, rmess[0]);
+			break;
+
 		    case DSP_CODEC_HKOFF:
 			mprintf("[%d/%d] Station OffHook\n",m_reg.cardnum,msgq[2]);
 			rmess[0] = DSP_LCODEC_HKOFF;
@@ -969,6 +977,19 @@ void VTCore::SetVDAAImpedance( int port, int impedance )
 	SetCountry( port, get_country(m_reg.cardtypnum, port) );
 } //}}}
 
+void VTCore::SetFlashTime( int port, uint16_t min, uint16_t max )
+{ //{{{
+	VT_DATA	     mess  = { board:    m_reg.cardtypnum,
+			       channel:  port,
+			       length:   (max << 16) | min,
+			       data:     NULL
+			     };
+
+	if( ioctl(pci_fd, VT_IOC_SETFLASH, &mess) < 0 )
+		mprintf("[%d/%d] VT_IOC_SETFLASH %u - %u FAILED: %m\n",
+					m_reg.cardnum, port, min, max);
+} //}}}
+
 float VTCore::GetHWPlayGain( unsigned int port )
 { //{{{
 	char procnode[128];
