@@ -80,21 +80,18 @@ DEFINE_MUTEX(vtcore_mutex);
 
 static int vtcore_open( struct inode*, struct file* );
 static int vtcore_release( struct inode*, struct file* );
-static int vtcore_ioctl( struct inode *inode,
-			 struct file *file,
-			 unsigned int cmd,
-			 unsigned long data);
+static long vtcore_ioctl(struct file *file, unsigned int cmd, unsigned long data);
 
 static struct file_operations vtcore_fops={
-	.owner   = THIS_MODULE,
-	.llseek  = NULL,
-	.read    = NULL,
-	.write   = NULL,
-	.poll    = NULL,
-	.ioctl   = vtcore_ioctl,
-	.open    = vtcore_open,
-	.release = vtcore_release,
-	.fasync  = NULL
+	.owner		= THIS_MODULE,
+	.llseek		= NULL,
+	.read		= NULL,
+	.write		= NULL,
+	.poll		= NULL,
+	.unlocked_ioctl	= vtcore_ioctl,
+	.open		= vtcore_open,
+	.release	= vtcore_release,
+	.fasync		= NULL
 };
 
 
@@ -421,7 +418,7 @@ static int check_channel(int board, int port)
 	return RET_OK;
 } //}}}
 
-static int vtcore_ioctl(struct inode *inode, struct file *file, unsigned int cmd, unsigned long data)
+static long vtcore_ioctl(struct file *file, unsigned int cmd, unsigned long data)
 { //{{{
 	VT_DATA	         vt_data;
 	VT_DATA	         vt_data2;
@@ -1282,7 +1279,6 @@ static struct file_operations board_tap_fops =
 	.release      = vtboard_tap_release,
 	.read         = vtboard_tap_read,
 	.write        = NULL,
-	.ioctl        = NULL,
 	.fasync       = NULL
 }; //}}}
 
